---
name: Documentation Update
about: Ask for a documentation Update
---

## Documentation Update: <NAME>

**Type**: ...
**Location**: ...

<!--
Relevant category for type are: Coverage | Bug in Example | Typos | Clarification
Adn give an indication of which part of the documentation this issue concerns.
The more precise the better.
Example:
**Type**: Coverage
**Location**: A Page under the How-To Sections
-->

## Abstract

<!--
Replace this comment with a A brief summary of the Documentation Update Request.
Example: Include a page describing how to define view arguments.
-->

## Motivation

<!--
Replace this comment with why this request is important, and will improve the documentation.
Example: View Arguments injection is a major feature of flask_jeroboam and should be documented
for users to use the package properly.
-->

## Current State

<!--
Replace this comment with a brief description of the current state of the documentation and what's wrong with it.
Exemple: The Page is missing, and users have to figure out how it works on their own.
-->

## What needs to be done

<!--
Replace this comment with what needs to be done. In the form of Tasks.
Example:
- [ ] Include the Page
- [ ] Cover how type hints work
- [ ] Cover how default location is solved based on the HTTP verb
- [ ] Cover how Function can help change location
- [ ] Include Examples
-->
